@@ -35,9 +35,9 @@
 #include <gtk/gtk.h>
 
 #include "burn-basics.h"
-#include "burn-medium.h"
+#include "brasero-medium.h"
 #include "burn-debug.h"
-#include "burn-drive.h"
+#include "brasero-drive.h"
 #include "brasero-utils.h"
 #include "brasero-session-cfg.h"
 #include "brasero-drive-properties.h"
@@ -159,7 +159,7 @@ brasero_drive_properties_set_tmpdir_info (BraseroDriveProperties *self,
 	vol_size = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_FILESYSTEM_FREE);
 	g_object_unref (info);
 
-	string = brasero_utils_get_size_string (vol_size, TRUE, TRUE);
+	string = g_format_size_for_display (vol_size);
 	gtk_label_set_text (GTK_LABEL (priv->tmpdir_size), string);
 	g_free (string);
 }
@@ -236,7 +236,7 @@ brasero_drive_properties_check_tmpdir (BraseroDriveProperties *self,
 						 _("Do you really want to choose this location?"));
 
 		string = g_strdup_printf ("%s.", error->message);
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), string);
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", string);
 		g_error_free (error);
 		g_free (string);
 
@@ -272,7 +272,7 @@ brasero_drive_properties_check_tmpdir (BraseroDriveProperties *self,
 						 _("Do you really want to choose this location?"));
 
 		string = g_strdup_printf ("%s.", _("You do not have the required permission to write at this location"));
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), string);
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", string);
 		g_free (string);
 
 		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
@@ -427,15 +427,20 @@ brasero_drive_properties_format_disc_speed (BraseroMedia media,
 	gchar *text;
 
 	if (media & BRASERO_MEDIUM_DVD)
+		/* Translators %s.1f is the speed used to burn */
 		text = g_strdup_printf (_("%.1f x (DVD)"),
 					BRASERO_RATE_TO_SPEED_DVD (rate));
 	else if (media & BRASERO_MEDIUM_CD)
+		/* Translators %s.1f is the speed used to burn */
 		text = g_strdup_printf (_("%.1f x (CD)"),
 					BRASERO_RATE_TO_SPEED_CD (rate));
 	else if (media & BRASERO_MEDIUM_BD)
+		/* Translators %s.1f is the speed used to burn */
 		text = g_strdup_printf (_("%.1f x (BD)"),
 					BRASERO_RATE_TO_SPEED_BD (rate));
 	else
+		/* Translators %s.1f is the speed used to burn for every medium
+		 * type*/
 		text = g_strdup_printf (_("%.1f x (BD) %.1f x (DVD) %.1f x (CD)"),
 					BRASERO_RATE_TO_SPEED_BD (rate),
 					BRASERO_RATE_TO_SPEED_DVD (rate),
