@@ -575,7 +575,8 @@ brasero_src_image_clicked (GtkButton *button)
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (priv->file), filter);
 
 	filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (filter, _("Image files only"));
+	/* Translators: this a disc image here */
+	gtk_file_filter_set_name (filter, C_("disc", "Image files only"));
 	gtk_file_filter_add_mime_type (filter, mimes [0]);
 	gtk_file_filter_add_mime_type (filter, mimes [1]);
 	gtk_file_filter_add_mime_type (filter, mimes [2]);
@@ -731,6 +732,16 @@ brasero_src_image_finalize (GObject *object)
 		priv->io = NULL;
 	}
 
+	if (priv->track) {
+		brasero_track_unref (priv->track);
+		priv->track = NULL;
+	}
+
+	if (priv->folder) {
+		g_free (priv->folder);
+		priv->folder = NULL;
+	}
+
 	G_OBJECT_CLASS (brasero_src_image_parent_class)->finalize (object);
 }
 
