@@ -35,6 +35,7 @@
 #include <errno.h>
 #include <string.h>
 #include <unistd.h>
+#include <sys/param.h>
 
 #include <glib.h>
 #include <glib-object.h>
@@ -54,8 +55,10 @@ struct _BraseroMkisofsBase {
 	gint excluded_fd;
 
 	GHashTable *grafts;
+	GHashTable *joliet;
 
 	guint found_video_ts:1;
+	guint use_joliet:1;
 };
 typedef struct _BraseroMkisofsBase BraseroMkisofsBase;
 
@@ -76,6 +79,8 @@ brasero_mkisofs_base_clean (BraseroMkisofsBase *base)
 		close (base->grafts_fd);
 	if (base->excluded_fd)
 		close (base->excluded_fd);
+	if (base->joliet)
+		g_hash_table_destroy (base->joliet);
 
 	if (base->grafts) {
 		g_hash_table_destroy (base->grafts);
@@ -136,14 +141,17 @@ brasero_mkisofs_base_write_excluded (BraseroMkisofsBase *base,
 
 		unescaped_uri = g_uri_unescape_string (uri, NULL);
 		localpath = g_filename_from_uri (unescaped_uri, NULL, NULL);
-		g_free (unescaped_uri);	      
+		g_free (unescaped_uri);
+
+		if (!localpath)
+			localpath = g_filename_from_uri (uri, NULL, NULL);					  
 	}
 	else {
 		BRASERO_BURN_LOG ("File not stored locally %s", uri);
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
-			     BRASERO_BURN_ERROR_GENERAL,
-			     _("the file is not stored locally"));
+			     BRASERO_BURN_ERROR_FILE_NOT_LOCAL,
+			     _("The file is not stored locally"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -236,7 +244,8 @@ _escape_path (const gchar *str)
 }
 
 static gchar *
-_build_graft_point (const gchar *uri, const gchar *discpath) {
+_build_graft_point (const gchar *uri, const gchar *discpath)
+{
 	gchar *escaped_discpath;
 	gchar *graft_point;
 	gchar *path;
@@ -283,15 +292,15 @@ brasero_mkisofs_base_write_graft (BraseroMkisofsBase *base,
 
 	/* build up graft and write it */
 	graft_point = _build_graft_point (uri, disc_path);
-
 	if (!graft_point) {
-		/* Translators: Error message saying no graft point is specified
-		 * A graft point is the path (on the disc) where a file from
-		 * any source will be added ("grafted") */
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("null graft point"));
+			     /* Translators: Error message saying no graft point
+			      * is specified. A graft point is the path (on the
+			      * disc) where a file from any source will be added
+			      * ("grafted") */
+			     _("An internal error occured"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -303,19 +312,156 @@ brasero_mkisofs_base_write_graft (BraseroMkisofsBase *base,
 	return BRASERO_BURN_OK;
 }
 
+/**
+ * Manages the Joliet incompatible names and mangles names if need be
+ */
+
+static GHashTable *
+brasero_mkisofs_base_mangle_joliet_name (GHashTable *joliet,
+					 const gchar *path,
+					 gchar *buffer)
+{
+	gboolean has_slash = FALSE;
+	gint dot_pos = -1;
+	gint dot_len = -1;
+	gchar *name;
+	gint width;
+	gint start;
+	gint num;
+	gint end;
+
+	/* NOTE: this wouldn't work on windows (not a big deal) */
+	end = strlen (path);
+	if (!end) {
+		buffer [0] = '\0';
+		return joliet;
+	}
+
+	memcpy (buffer, path, MIN (end, MAXPATHLEN));
+	buffer [MIN (end, MAXPATHLEN)] = '\0';
+
+	/* move back until we find a character different from G_DIR_SEPARATOR */
+	end --;
+	while (end >= 0 && G_IS_DIR_SEPARATOR (path [end])) {
+		end --;
+		has_slash = TRUE;
+	}
+
+	/* There are only slashes */
+	if (end == -1)
+		return joliet;
+
+	start = end - 1;
+	while (start >= 0 && !G_IS_DIR_SEPARATOR (path [start])) {
+		/* Find the extension while at it */
+		if (dot_pos <= 0 && path [start] == '.')
+			dot_pos = start;
+
+		start --;
+	}
+
+	if (end - start <= 64)
+		return joliet;
+
+	name = buffer + start + 1;
+	if (dot_pos > 0)
+		dot_len = end - dot_pos + 1;
+
+	if (dot_len > 1 && dot_len < 5)
+		memcpy (name + 64 - dot_len,
+			path + dot_pos,
+			dot_len);
+
+	name [64] = '\0';
+
+	if (!joliet) {
+		joliet = g_hash_table_new_full (g_str_hash,
+						g_str_equal,
+						g_free,
+						NULL);
+
+		g_hash_table_insert (joliet, g_strdup (buffer), GINT_TO_POINTER (1));
+		if (has_slash)
+			strcat (buffer, G_DIR_SEPARATOR_S);
+
+		BRASERO_BURN_LOG ("Mangled name to %s (truncated)", buffer);
+		return joliet;
+	}
+
+	/* see if this path was already used */
+	num = GPOINTER_TO_INT (g_hash_table_lookup (joliet, buffer));
+	if (!num) {
+		g_hash_table_insert (joliet, g_strdup (buffer), GINT_TO_POINTER (1));
+
+		if (has_slash)
+			strcat (buffer, G_DIR_SEPARATOR_S);
+
+		BRASERO_BURN_LOG ("Mangled name to %s (truncated)", buffer);
+		return joliet;
+	}
+
+	/* NOTE: g_hash_table_insert frees key_path */
+	num ++;
+	g_hash_table_insert (joliet, g_strdup (buffer), GINT_TO_POINTER (num));
+
+	width = 1;
+	while (num / (width * 10)) width ++;
+
+	/* try to keep the extension */
+	if (dot_len < 5 && dot_len > 1 )
+		sprintf (name + (64 - width - dot_len),
+			 "%i%s",
+			 num,
+			 path + dot_pos);
+	else
+		sprintf (name + (64 - width),
+			 "%i",
+			 num);
+
+	if (has_slash)
+		strcat (buffer, G_DIR_SEPARATOR_S);
+
+	BRASERO_BURN_LOG ("Mangled name to %s", buffer);
+	return joliet;
+}
+
 static gboolean
 _foreach_write_grafts (const gchar *uri,
 		       GSList *grafts,
 		       BraseroWriteGraftData *data)
 {
+	gchar buffer [MAXPATHLEN];
 	BraseroBurnResult result;
 	BraseroGraftPt *graft;
 
 	for (; grafts; grafts = grafts->next) {
+		const gchar *path;
+
 		graft = grafts->data;
+
+		if (!graft->path) {
+			result = brasero_mkisofs_base_write_graft (data->base,
+								   graft->uri,
+								   NULL,
+								   data->error);
+			if (result != BRASERO_BURN_OK)
+				return TRUE;
+
+			continue;
+		}
+
+		if (data->base->use_joliet) {
+			data->base->joliet = brasero_mkisofs_base_mangle_joliet_name (data->base->joliet,
+										      graft->path,
+										      buffer);
+			path = buffer;
+		}
+		else
+			path = graft->path;
+
 		result = brasero_mkisofs_base_write_graft (data->base,
 							   graft->uri,
-							   graft->path,
+							   path,
 							   data->error);
 		if (result != BRASERO_BURN_OK)
 			return TRUE;
@@ -350,11 +496,22 @@ brasero_mkisofs_base_empty_directory (BraseroMkisofsBase *base,
 				      GError **error)
 {
 	BraseroBurnResult result;
+	gchar buffer [MAXPATHLEN];
 	gchar *graft_point;
+	const gchar *path;
 
-	/* This a special case for uri = NULL; that
-	 * is treated as if it were a directory */
-	graft_point = _build_graft_point (base->emptydir, disc_path);
+	/* Mangle the name in case joliet is required */
+	if (base->use_joliet) {
+		base->joliet = brasero_mkisofs_base_mangle_joliet_name (base->joliet,
+									disc_path,
+									buffer);
+		path = buffer;
+	}
+	else
+		path = disc_path;
+
+	/* Special case for uri = NULL; that is treated as if it were a directory */
+	graft_point = _build_graft_point (base->emptydir, path);
 	result = _write_line (base->grafts_fd, graft_point, error);
 	g_free (graft_point);
 
@@ -425,8 +582,8 @@ brasero_mkisofs_base_add_graft (BraseroMkisofsBase *base,
 		BRASERO_BURN_LOG ("File not stored locally %s", graft->uri);
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
-			     BRASERO_BURN_ERROR_GENERAL,
-			     _("the file is not stored locally"));
+			     BRASERO_BURN_ERROR_FILE_NOT_LOCAL,
+			     _("The file is not stored locally"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -475,6 +632,7 @@ brasero_mkisofs_base_add_graft (BraseroMkisofsBase *base,
 BraseroBurnResult
 brasero_mkisofs_base_write_to_files (GSList *grafts,
 				     GSList *excluded,
+				     gboolean use_joliet,
 				     const gchar *emptydir,
 				     const gchar *videodir,
 				     const gchar *grafts_path,
@@ -515,6 +673,7 @@ brasero_mkisofs_base_write_to_files (GSList *grafts,
 		return BRASERO_BURN_ERR;
 	}
 
+	base.use_joliet = use_joliet;
 	base.emptydir = emptydir;
 	base.videodir = videodir;
 
