@@ -505,22 +505,30 @@ brasero_burn_uri_start_thread (BraseroBurnURI *self,
 			       GError **error)
 {
 	BraseroBurnURIPrivate *priv;
+	GError *thread_error = NULL;
 
 	priv = BRASERO_BURN_URI_PRIVATE (self);
 
 	if (priv->thread)
 		return BRASERO_BURN_RUNNING;
 
+	priv->cancel = g_cancellable_new ();
+
 	g_mutex_lock (priv->mutex);
 	priv->thread = g_thread_create (brasero_burn_uri_thread,
 					self,
 					TRUE,
-					error);
+					&thread_error);
 	g_mutex_unlock (priv->mutex);
-	if (!priv->thread) 
-		return BRASERO_BURN_ERR;
 
-	priv->cancel = g_cancellable_new ();
+	/* Reminder: this is not necessarily an error as the thread may have finished */
+	//if (!priv->thread)
+	//	return BRASERO_BURN_ERR;
+	if (thread_error) {
+		g_propagate_error (error, thread_error);
+		return BRASERO_BURN_ERR;
+	}
+
 	return BRASERO_BURN_OK;
 }
 
